@@ -92,3 +92,67 @@ function getFacebookAccessToken() {
     oauthDialog.state = "show";
     mouseArea.enabled = true;
 }
+
+function loadComments() {
+    commentsModel.loading = true;
+
+    var doc = new XMLHttpRequest();
+    doc.onreadystatechange = function() {
+        if (doc.readyState == XMLHttpRequest.DONE) {
+            var xml = doc.responseText;
+            commentsModel.setXml(xml);
+
+            commentsModel.loading = false;
+            commentsList.loaded = true;
+        }
+    }
+    doc.open("GET", commentsList.commentsFeed);
+    doc.send();
+}
+
+function appendComments() {
+    commentsModel.loading = true;
+
+    var doc = new XMLHttpRequest();
+    doc.onreadystatechange = function() {
+        if (doc.readyState == XMLHttpRequest.DONE) {
+            var xml = doc.responseText;
+            commentsModel.appendXml(xml);
+
+            commentsModel.loading = false;
+        }
+    }
+    doc.open("GET", commentsList.commentsFeed + "&start-index=" + (commentsModel.count + 1).toString());
+    doc.send();
+}
+
+function loadRelatedVideos() {
+    var doc = new XMLHttpRequest();
+    doc.onreadystatechange = function() {
+        if (doc.readyState == XMLHttpRequest.DONE) {
+            var xml = doc.responseText;
+            relatedModel.setXml(xml);
+
+            relatedModel.loading = false;
+            relatedView.loaded = true;
+        }
+    }
+    doc.open("GET", relatedView.videoFeed);
+    doc.send();
+}
+
+function appendRelatedVideos() {
+    relatedModel.loading = true;
+
+    var doc = new XMLHttpRequest();
+    doc.onreadystatechange = function() {
+        if (doc.readyState == XMLHttpRequest.DONE) {
+            var xml = doc.responseText;
+            relatedModel.appendXml(xml);
+
+            relatedModel.loading = false;
+        }
+    }
+    doc.open("GET", relatedView.videoFeed + "&start-index=" + (relatedModel.count + 1).toString());
+    doc.send();
+}
